@@ -89,6 +89,10 @@ msAbund <- function(formula, data, inits, priors, tuning,
     if (n.thin > n.samples) {
       stop("error: n.thin must be less than n.samples")
     }
+    # Check if n.burn, n.thin, and n.samples result in an integer and error if otherwise.
+    if (((n.samples - n.burn) / n.thin) %% 1 != 0) {
+      stop("the number of posterior samples to save ((n.samples - n.burn) / n.thin) is not a whole number. Please respecify the MCMC criteria such that the number of posterior samples saved is a whole number.")
+    }
     # For later
     y.mat <- y
     # Offset
@@ -512,7 +516,7 @@ msAbund <- function(formula, data, inits, priors, tuning,
 	}
       } else {
         message("beta.star is not specified in initial values.\nSetting initial values from the prior.\n")
-        beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+        beta.star.inits <- rnorm(n.abund.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
         # Starting values for all species
         beta.star.inits <- rep(beta.star.inits, n.sp)
       }
@@ -683,7 +687,7 @@ msAbund <- function(formula, data, inits, priors, tuning,
         }
         if (p.abund.re > 0) {
           sigma.sq.mu.inits <- runif(p.abund.re, 0.05, 1)
-          beta.star.inits <- rnorm(n.abund.re, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
+          beta.star.inits <- rnorm(n.abund.re, 0, sqrt(sigma.sq.mu.inits[beta.star.indx + 1]))
           beta.star.inits <- rep(beta.star.inits, n.sp)
         }
       }
