@@ -6,6 +6,7 @@
 #include <omp.h>
 #endif
 
+#define R_NO_REMAP
 #include <R.h>
 #include <Rmath.h>
 #include <Rinternals.h>
@@ -19,12 +20,12 @@
 extern "C" {
 
   SEXP sfMsNMixNNGPPredict(SEXP coords_r, SEXP J_r, SEXP family_r, SEXP nSp_r, SEXP q_r,
-		           SEXP pAbund_r, SEXP m_r, SEXP X0_r, SEXP coords0_r, 
-			   SEXP JStr_r, SEXP nnIndx0_r, SEXP betaSamples_r, 
-			   SEXP thetaSamples_r, SEXP kappaSamples_r, SEXP lambdaSamples_r, 
-			   SEXP wSamples_r, SEXP betaStarSiteSamples_r, 
-			   SEXP nSamples_r, SEXP covModel_r, SEXP nThreads_r, SEXP verbose_r, 
-			   SEXP nReport_r, SEXP sitesLink_r, SEXP sites0Sampled_r){
+                           SEXP pAbund_r, SEXP m_r, SEXP X0_r, SEXP coords0_r,
+                           SEXP JStr_r, SEXP nnIndx0_r, SEXP betaSamples_r,
+                           SEXP thetaSamples_r, SEXP kappaSamples_r, SEXP lambdaSamples_r,
+                           SEXP wSamples_r, SEXP betaStarSiteSamples_r,
+                           SEXP nSamples_r, SEXP covModel_r, SEXP nThreads_r, SEXP verbose_r,
+                           SEXP nReport_r, SEXP sitesLink_r, SEXP sites0Sampled_r){
 
     int i, j, k, l, s, info, nProtect=0, ll;
     const int inc = 1;
@@ -32,11 +33,11 @@ extern "C" {
     char const *ntran = "N";
     const double zero = 0.0;
     char const *lower = "L";
-    
+
     double *coords = REAL(coords_r);
     int J = INTEGER(J_r)[0];
     int nSp = INTEGER(nSp_r)[0];
-    int q = INTEGER(q_r)[0]; 
+    int q = INTEGER(q_r)[0];
     int pAbund = INTEGER(pAbund_r)[0];
     int pAbundnSp = pAbund * nSp;
     int Jq = J * q;
@@ -48,35 +49,35 @@ extern "C" {
     int JStr = INTEGER(JStr_r)[0];
     int JStrnSp = JStr * nSp;
     int JStrq = JStr * q;
-    int m = INTEGER(m_r)[0]; 
-    int mm = m * m; 
+    int m = INTEGER(m_r)[0];
+    int mm = m * m;
     int *sitesLink = INTEGER(sitesLink_r);
     int *sites0Sampled = INTEGER(sites0Sampled_r);
 
-    int *nnIndx0 = INTEGER(nnIndx0_r);        
+    int *nnIndx0 = INTEGER(nnIndx0_r);
     double *beta = REAL(betaSamples_r);
     double *kappa = REAL(kappaSamples_r);
     double *theta = REAL(thetaSamples_r);
     double *lambda = REAL(lambdaSamples_r);
     double *w = REAL(wSamples_r);
     double *betaStarSite = REAL(betaStarSiteSamples_r);
-    
+
     int nSamples = INTEGER(nSamples_r)[0];
     int covModel = INTEGER(covModel_r)[0];
     std::string corName = getCorName(covModel);
     int nThreads = INTEGER(nThreads_r)[0];
     int verbose = INTEGER(verbose_r)[0];
     int nReport = INTEGER(nReport_r)[0];
-    
+
 #ifdef _OPENMP
     omp_set_num_threads(nThreads);
 #else
     if(nThreads > 1){
-      warning("n.omp.threads > 1, but source not compiled with OpenMP support.");
+      Rf_warning("n.omp.threads > 1, but source not compiled with OpenMP support.");
       nThreads = 1;
     }
 #endif
-    
+
     if(verbose){
       Rprintf("----------------------------------------\n");
       Rprintf("\tPrediction description\n");
@@ -87,14 +88,14 @@ extern "C" {
       Rprintf("Using %i nearest neighbors.\n", m);
       Rprintf("Using %i latent spatial factors.\n\n", q);
       Rprintf("Number of MCMC samples %i.\n\n", nSamples);
-      Rprintf("Predicting at %i non-sampled locations.\n", JStr);  
+      Rprintf("Predicting at %i non-sampled locations.\n", JStr);
 #ifdef _OPENMP
       Rprintf("\nSource compiled with OpenMP support and model fit using %i threads.\n", nThreads);
 #else
       Rprintf("\n\nSource not compiled with OpenMP support.\n");
 #endif
-    } 
-    
+    }
+
     // parameters
     int nTheta, phiIndx, nuIndx;
 
@@ -106,17 +107,17 @@ extern "C" {
 	nTheta = 2; //phi, nu
 	phiIndx = 0; nuIndx = 1;
       }
-   
-    int nThetaq = nTheta * q; 
+
+    int nThetaq = nTheta * q;
     // get max nu
     double *nuMax = (double *) R_alloc(q, sizeof(double));
-    int *nb = (int *) R_alloc(q, sizeof(nb)); 
+    int *nb = (int *) R_alloc(q, sizeof(nb));
     // Fill in with zeros
     for (ll = 0; ll < q; ll++) {
-      nuMax[ll] = 0.0; 
-      nb[ll] = 0; 
+      nuMax[ll] = 0.0;
+      nb[ll] = 0;
     }
-    
+
     if(corName == "matern"){
       for (ll = 0; ll < q; ll++) {
         for(s = 0; s < nSamples; s++){
@@ -128,10 +129,10 @@ extern "C" {
       }
     }
 
-    int nbMax = 0; 
+    int nbMax = 0;
     for (ll = 0; ll < q; ll++) {
       if (nb[ll] > nbMax) {
-        nbMax = nb[ll]; 
+        nbMax = nb[ll];
       }
     }
 
@@ -143,11 +144,11 @@ extern "C" {
     int threadID = 0, status = 0;
 
     SEXP N0_r, w0_r, mu0_r;
-    PROTECT(N0_r = allocMatrix(REALSXP, JStrnSp, nSamples)); nProtect++; 
-    PROTECT(mu0_r = allocMatrix(REALSXP, JStrnSp, nSamples)); nProtect++; 
-    PROTECT(w0_r = allocMatrix(REALSXP, JStrq, nSamples)); nProtect++;
+    PROTECT(N0_r = Rf_allocMatrix(REALSXP, JStrnSp, nSamples)); nProtect++;
+    PROTECT(mu0_r = Rf_allocMatrix(REALSXP, JStrnSp, nSamples)); nProtect++;
+    PROTECT(w0_r = Rf_allocMatrix(REALSXP, JStrq, nSamples)); nProtect++;
     double *N0 = REAL(N0_r);
-    double *mu0 = REAL(mu0_r); 
+    double *mu0 = REAL(mu0_r);
     double *w0 = REAL(w0_r);
     double *w0Star = (double *) R_alloc(nSamples * JStrnSp, sizeof(double));
     if (verbose) {
@@ -163,20 +164,20 @@ extern "C" {
     double *wV = (double *) R_alloc(JStrq*nSamples, sizeof(double));
 
     GetRNGstate();
-    
+
     for(i = 0; i < JStrq*nSamples; i++){
       wV[i] = rnorm(0.0,1.0);
     }
-    
+
     for(j = 0; j < JStr; j++){
       for (ll = 0; ll < q; ll++) {
 #ifdef _OPENMP
 #pragma omp parallel for private(threadID, phi, nu, sigmaSq, k, l, d, info)
-#endif     
+#endif
         for(s = 0; s < nSamples; s++){
 #ifdef _OPENMP
 	  threadID = omp_get_thread_num();
-#endif 	
+#endif
 	  if (sites0Sampled[j] == 1) {
             w0[s * JStrq + j * q + ll] = w[s * Jq + sitesLink[j] * q + ll];
 	  } else {
@@ -195,10 +196,10 @@ extern "C" {
 	      }
 	    }
 
-	    F77_NAME(dpotrf)(lower, &m, &C[threadID*mm], &m, &info FCONE); 
-	    if(info != 0){error("c++ error: dpotrf failed\n");}
-	    F77_NAME(dpotri)(lower, &m, &C[threadID*mm], &m, &info FCONE); 
-	    if(info != 0){error("c++ error: dpotri failed\n");}
+	    F77_NAME(dpotrf)(lower, &m, &C[threadID*mm], &m, &info FCONE);
+	    if(info != 0){Rf_error("c++ error: dpotrf failed\n");}
+	    F77_NAME(dpotri)(lower, &m, &C[threadID*mm], &m, &info FCONE);
+	    if(info != 0){Rf_error("c++ error: dpotri failed\n");}
 
 	    F77_NAME(dsymv)(lower, &m, &one, &C[threadID*mm], &m, &c[threadID*m], &inc, &zero, &tmp_m[threadID*m], &inc FCONE);
 
@@ -209,7 +210,7 @@ extern "C" {
 
 	    #ifdef _OPENMP
             #pragma omp atomic
-            #endif   
+            #endif
 	    vIndx++;
 
 	    w0[s * JStrq + j * q + ll] = sqrt(sigmaSq - F77_NAME(ddot)(&m, &tmp_m[threadID*m], &inc, &c[threadID*m], &inc))*wV[vIndx] + d;
@@ -258,31 +259,31 @@ extern "C" {
     } // j
 
     PutRNGstate();
-    
+
     //make return object
     SEXP result_r, resultName_r;
     int nResultListObjs = 3;
 
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     SET_VECTOR_ELT(result_r, 0, N0_r);
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("N.0.samples")); 
-    
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("N.0.samples"));
+
     SET_VECTOR_ELT(result_r, 1, w0_r);
-    SET_VECTOR_ELT(resultName_r, 1, mkChar("w.0.samples"));
+    SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("w.0.samples"));
 
     SET_VECTOR_ELT(result_r, 2, mu0_r);
-    SET_VECTOR_ELT(resultName_r, 2, mkChar("mu.0.samples")); 
+    SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("mu.0.samples"));
+
+    Rf_namesgets(result_r, resultName_r);
 
-    namesgets(result_r, resultName_r);
-    
     //unprotect
     UNPROTECT(nProtect);
-    
+
     return(result_r);
-  
+
   }
 }
 
-    
+
